"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.amplicodePipeline = void 0;
const amplicode_1 = require("../stages/options/pieces/amplicode");
const defaultGetOptions_1 = require("../stages/options/defaultGetOptions");
const defaultConfigureGenerator_1 = require("../stages/configuring/defaultConfigureGenerator");
const amplicodeGetAnswers_1 = require("../stages/answers/amplicodeGetAnswers");
const amplicodeDeriveTemplateModel_1 = require("../stages/template-model/amplicodeDeriveTemplateModel");
const amplicodeWrite_1 = require("../stages/writing/amplicodeWrite");
const amplicodeGetGraphQLSchema_1 = require("../stages/graphql-schema/amplicodeGetGraphQLSchema");
async function amplicodePipeline(input, gen) {
    const { templateDir, questions = [], optionsConfig = amplicode_1.amplicodeCommonOptionsConfig } = input;
    const { getOptions = defaultGetOptions_1.defaultGetOptions, configureGenerator = defaultConfigureGenerator_1.defaultConfigureGenerator, getAnswers = amplicodeGetAnswers_1.amplicodeGetAnswers, getGraphQLSchema = amplicodeGetGraphQLSchema_1.amplicodeGetGraphQLSchema, deriveTemplateModel = amplicodeDeriveTemplateModel_1.amplicodeDeriveTemplateModel, write = amplicodeWrite_1.amplicodeWrite } = input.stages ?? {};
    // Setting the generator's destinationRoot (which happens inside configureGenerator) will change the current working directory,
    // therefore we need to save the directory from which the generator command was invoked.
    const invocationDir = process.cwd();
    // Obtain the options passed from command line
    const options = await getOptions(optionsConfig, gen);
    // Apply default configuration to the Yeoman generator
    await configureGenerator(templateDir, gen, options);
    // Obtain GraphQL schema
    const schema = await getGraphQLSchema(options, invocationDir);
    // Obtain answers
    const answers = await getAnswers(options, gen, questions);
    // // Derive template model from options, answers and GraphQL schema
    const templateModel = await deriveTemplateModel(options, answers, schema);
    // Write files to disk, performing interpolations using the template model
    await write(templateModel, gen);
}
exports.amplicodePipeline = amplicodePipeline;
//# sourceMappingURL=amplicodePipeline.js.map