"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getEntityAttributes = void 0;
const graphql_1 = require("graphql");
const getTopFieldName_1 = require("./getTopFieldName");
const utils_1 = require("../../../../../common/utils");
const getAttributeNames_1 = require("./getAttributeNames");
const getEntityName_1 = require("./getEntityName");
const getTypeFields_1 = require("./getTypeFields");
const isAnyLeafType_1 = require("./isAnyLeafType");
const getSelectedFieldNamesFromTopField_1 = require("./getSelectedFieldNamesFromTopField");
function getEntityAttributes(documentNode, schema, idField) {
    // e.g. "petList"
    const queryFieldName = getTopFieldName_1.getTopFieldName(documentNode);
    // e.g. "PetDTO"
    const entityName = getEntityName_1.getEntityName(queryFieldName, schema);
    const typeFields = getTypeFields_1.getTypeFields(entityName, schema);
    const selectedFieldNames = getSelectedFieldNamesFromTopField_1.getSelectedFieldNamesFromTopField(documentNode);
    if (!selectedFieldNames.find(fieldKey => typeFields[fieldKey].name === idField)) {
        throw new Error(`${queryFieldName} query attributes did not contain id attribute with name '${idField}', ` +
            `which required for screen generation`);
    }
    return selectedFieldNames
        // Do not include id attribute
        .filter(fieldKey => typeFields[fieldKey].name !== idField)
        .map(fieldKey => {
        const field = typeFields[fieldKey];
        const fieldType = (field.type instanceof graphql_1.GraphQLList || field.type instanceof graphql_1.GraphQLNonNull)
            ? field.type.ofType.name
            : field.type.name;
        return {
            name: field.name,
            displayName: utils_1.capitalizeFirst(utils_1.splitByCapitalLetter(field.name)),
            isRelationField: !(isAnyLeafType_1.isAnyLeafType(field.type)),
            type: fieldType,
            nestedAttributes: isAnyLeafType_1.isAnyLeafType(field.type)
                ? undefined
                : getAttributeNames_1.getAttributeNames(fieldType, schema),
        };
    });
}
exports.getEntityAttributes = getEntityAttributes;
//# sourceMappingURL=getEntityAttributes.js.map