"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const chai_1 = require("chai");
const getEntityAttributes_1 = require("./getEntityAttributes");
const test_commons_1 = require("../../../../../test/test-commons");
describe('getEntityAttributes', async () => {
    let schema;
    before(async () => {
        schema = await test_commons_1.getMockSchema();
    });
    it('derives a list of entity attributes', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_NODE, schema, 'id');
        chai_1.expect(attributes.sort()).to.deep.equal(RESULT.sort());
    });
    it('relation field is marked as such', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_NODE, schema, 'id');
        const ownerAttr = attributes.find(attr => attr.name === 'owner');
        chai_1.expect(ownerAttr?.isRelationField).to.eq(true);
    });
    it('relation field has entity name', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_NODE, schema, 'id');
        const ownerAttr = attributes.find(attr => attr.name === 'owner');
        chai_1.expect(ownerAttr?.type).to.eq('OwnerDTO');
    });
    it('query contains id attribute with custom name', () => {
        const attributes = getEntityAttributes_1.getEntityAttributes(QUERY_WITHOUT_ID, schema, 'identificationNumber');
        const dateAttr = attributes.find(attr => attr.name === 'birthDate');
        chai_1.expect(dateAttr?.type).to.eq('Date');
    });
    it('fails if there is no "id" attribute in query', () => {
        chai_1.expect(() => getEntityAttributes_1.getEntityAttributes(QUERY_WITHOUT_ID, schema, 'id'))
            .to.throw("pet query attributes did not contain id attribute with name 'id', " +
            "which required for screen generation");
    });
});
const QUERY_WITHOUT_ID = graphql_tag_1.default(`
  query Get_Pet($id: BigInteger) {
    pet(id: $id) {
      identificationNumber
      birthDate
    }
  }
`);
const QUERY_NODE = graphql_tag_1.default(`
    query Get_Pet_List {
        petList {
            id
            identificationNumber
            owner {
                firstName
                lastName
            }
            type {
                id
            }
        }
    }
`);
const RESULT = [
    {
        nestedAttributes: undefined,
        displayName: "Identification Number",
        isRelationField: false,
        name: "identificationNumber",
        type: "String",
    },
    {
        nestedAttributes: [
            "address",
            "city",
            "email",
            "firstName",
            "id",
            "lastName",
            "telephone",
        ],
        displayName: "Owner",
        isRelationField: true,
        name: "owner",
        type: "OwnerDTO",
    },
    {
        nestedAttributes: [
            "defenseStatus",
            "id",
            "name"
        ],
        displayName: "Type",
        isRelationField: true,
        name: "type",
        type: "PetTypeDTO",
    },
];
//# sourceMappingURL=getEntityAttributes.test.js.map