"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const test_commons_1 = require("../../../../../test/test-commons");
const getGraphQLTypeByRelativePath_1 = require("./getGraphQLTypeByRelativePath");
const chai_1 = require("chai");
describe('getGraphQLTypeByRelativePath', async () => {
    let schema;
    before(async () => {
        schema = await test_commons_1.getMockSchema();
    });
    it('with mutation startField', () => {
        const mutationType = schema.getMutationType();
        if (mutationType == null)
            throw new Error();
        const petType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, mutationType, ['updatePet']);
        chai_1.expect(petType.toString()).to.eq('PetDTO');
        const identificationNumberType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, mutationType, ['updatePet', 'identificationNumber']);
        chai_1.expect(identificationNumberType.toString()).to.eq('String');
    });
    it('with query startField', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const petType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet']);
        chai_1.expect(petType.toString()).to.eq('PetDTO');
        const identificationNumberType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet', 'identificationNumber']);
        chai_1.expect(identificationNumberType.toString()).to.eq('String');
    });
    it('in root of query', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const queryStringType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, []);
        chai_1.expect(queryStringType.toString()).to.eq('Query');
        const petType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet']);
        const petStringType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, petType, []);
        chai_1.expect(petStringType.toString()).to.eq('PetDTO');
        const petListType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['petList']);
        const petListStringType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, petListType, []);
        chai_1.expect(petListStringType.toString()).to.eq('[PetDTO]');
    });
    // TODO enable when TestDTO will be added to the graphql schema
    xit('with primitive', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const testType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['testList']);
        const floatType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['floatTest']);
        chai_1.expect(floatType).to.eq('Float');
        const intType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['intTest']);
        chai_1.expect(intType).to.eq('Int');
        const booleanType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['bool']);
        chai_1.expect(booleanType).to.eq('Boolean');
        const stringType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['string']);
        chai_1.expect(stringType).to.eq('String');
    });
    // TODO enable when TestDTO will be added to the graphql schema
    xit('with date', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const testType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['testList']);
        const localDateType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['localDate']);
        chai_1.expect(localDateType).to.eq('Date');
        const localDateTimeType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['localDateTime']);
        chai_1.expect(localDateTimeType).to.eq('DateTime');
        const localTimeType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['localTime']);
        chai_1.expect(localTimeType).to.eq('Time');
    });
    // TODO enable when TestDTO will be added to the graphql schema
    xit('with not null', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const testType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['testList']);
        const strictBooleanType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['boolPrimitive']);
        chai_1.expect(strictBooleanType).to.eq('Boolean!');
        const strictIntType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, testType, ['bytePrimitive']);
        chai_1.expect(strictIntType).to.eq('Int!');
    });
    it('with array', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const petListType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['petList']);
        chai_1.expect(petListType.toString()).to.eq('[PetDTO]');
    });
    it('get type by deep path', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const ownerType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet', 'owner']);
        chai_1.expect(ownerType.toString()).to.eq('OwnerDTO');
        const ownerCityType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet', 'owner', 'city']);
        chai_1.expect(ownerCityType.toString()).to.eq('String');
        const ownerEmailType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet', 'owner', 'email']);
        chai_1.expect(ownerEmailType.toString()).to.eq('String');
        const petTypeType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet', 'type']);
        chai_1.expect(petTypeType.toString()).to.eq('PetTypeDTO');
        const petTypeNameType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, queryType, ['pet', 'type', 'name']);
        chai_1.expect(petTypeNameType.toString()).to.eq('String');
    });
    it('in argument', () => {
        const queryType = schema.getQueryType();
        if (queryType == null)
            throw new Error();
        const filterArgType = queryType.getFields()['ownerByNamesList'].args.find(({ name }) => name === 'filter')?.type;
        if (filterArgType == null)
            throw new Error();
        chai_1.expect(filterArgType.toString()).to.eq('OwnerFilterInput');
        const firstNameType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, filterArgType, ['firstName']);
        chai_1.expect(firstNameType.toString()).to.eq('String');
        const lastNameType = getGraphQLTypeByRelativePath_1.getGraphQLTypeByRelativePath(schema, filterArgType, ['lastName']);
        chai_1.expect(lastNameType.toString()).to.eq('String');
    });
});
//# sourceMappingURL=getGraphQLTypeByRelativePath.test.js.map