"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getRelations = exports.getRelationImports = void 0;
const template_model_1 = require("../../../../generators/react-typescript/common/template-model");
const cuba_model_utils_1 = require("../../../../common/model/cuba-model-utils");
function getRelationImports(relations, entity) {
    const entities = Object.values(relations);
    entities.unshift(entity);
    return entities
        // todo - need to think about className collision here (same className with different path)
        .reduce(// remove identical Imports (className and path both match)
    (acc, relationImport) => {
        if (!acc.some(ri => ri.className == relationImport.className && ri.path == relationImport.path)) {
            acc.push(relationImport);
        }
        return acc;
    }, []);
}
exports.getRelationImports = getRelationImports;
function getRelations(projectModel, attributes) {
    return attributes.reduce((relations, attribute) => {
        if (attribute.type == null || (attribute.mappingType !== 'ASSOCIATION' && attribute.mappingType !== 'COMPOSITION')) {
            return relations;
        }
        const entity = cuba_model_utils_1.findEntity(projectModel, attribute.type.entityName);
        if (entity) {
            const entityWithPath = {
                ...entity,
                path: template_model_1.getEntityPath(entity, projectModel)
            };
            if (attribute.mappingType === 'ASSOCIATION') {
                relations.associations[attribute.name] = entityWithPath;
            }
            if (attribute.mappingType === 'COMPOSITION') {
                relations.compositions[attribute.name] = entityWithPath;
            }
        }
        return relations;
    }, { associations: {}, compositions: {} });
}
exports.getRelations = getRelations;
//# sourceMappingURL=relations.js.map