"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.createEnums = void 0;
const typescript_1 = __importDefault(require("typescript"));
const utils_1 = require("../../../../../../common/utils");
function createEnums(enums) {
    const enDeclarations = [];
    const duplicates = [];
    enums
        .sort((a, b) => a.fqn.localeCompare(b.fqn))
        .forEach(e => {
        const className = e.className;
        const ed = typescript_1.default.createEnumDeclaration(undefined, [typescript_1.default.createToken(typescript_1.default.SyntaxKind.ExportKeyword)], className, getEnumMembers(e.values));
        if (enDeclarations.some(ed => ed.node.name.text === className)) {
            duplicates.push(className);
        }
        enDeclarations.push({ fqn: e.fqn, node: ed });
    });
    duplicates.forEach(duplicateName => {
        enDeclarations
            .filter(ed => ed.node.name.text === duplicateName)
            .forEach(ed => {
            ed.node = typescript_1.default.createEnumDeclaration(undefined, [typescript_1.default.createToken(typescript_1.default.SyntaxKind.ExportKeyword)], utils_1.fqnToName(ed.fqn), ed.node.members);
        });
    });
    return enDeclarations;
}
exports.createEnums = createEnums;
function getEnumMembers(values) {
    const members = [];
    values.forEach(v => {
        members.push(typescript_1.default.createEnumMember(v.name, typescript_1.default.createStringLiteral(v.name)));
    });
    return members;
}
//# sourceMappingURL=enums-generation.js.map