"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getNewComponentPreview = exports.addComponent = exports.registerComponentPreviews = void 0;
const path_1 = __importDefault(require("path"));
const utils_1 = require("../../../common/utils");
const jscodeshift_1 = __importStar(require("jscodeshift"));
function registerComponentPreviews(fs, { destRoot, dirShift, pathPattern, componentFileName, componentClassName }, isDefaultExport, componentProps, registerComponentCallback = exports.addComponent) {
    let isComponentRegistered = false;
    const componentPreviewsDir = path_1.default.join(destRoot, dirShift ? dirShift : '');
    const componentPreviewsPath = path_1.default.join(componentPreviewsDir, 'dev', 'previews.tsx');
    const componentPath = `../${getRelativePath(componentPreviewsDir, destRoot)}/${componentFileName}`;
    if (fs.exists(componentPreviewsPath)) {
        const componentPreviewsContents = fs.read(componentPreviewsPath);
        fs.write(componentPreviewsPath, registerComponentCallback(componentPreviewsContents, { pathPattern, componentClassName, componentFileName, componentPath }, isDefaultExport, componentProps));
        isComponentRegistered = true;
    }
    return isComponentRegistered;
}
exports.registerComponentPreviews = registerComponentPreviews;
const addComponent = (componentPreviewsContents, { pathPattern, componentClassName, componentPath }, isDefaultExport, componentProps) => {
    const tsxParser = jscodeshift_1.default.withParser('tsx');
    const previewsAST = tsxParser(componentPreviewsContents);
    addComponentImport(previewsAST, isDefaultExport, componentClassName, componentPath);
    const newComponentPreview = getNewComponentPreview(pathPattern, componentClassName, componentProps);
    return addComponentToPreview(previewsAST, newComponentPreview);
};
exports.addComponent = addComponent;
function getRelativePath(routingDir, destRoot) {
    return utils_1.convertToUnixPath(path_1.default.relative(routingDir, destRoot));
}
function getNewComponentPreview(pathPattern, componentClassName, componentProps) {
    return `
  <ComponentPreview path="${pathPattern}">
    <${componentClassName} ${serializeComponentsProps(componentClassName, componentProps)}/>
  </ComponentPreview>`;
}
exports.getNewComponentPreview = getNewComponentPreview;
function addComponentImport(previewsAST, isDefaultExport, componentClassName, componentPath) {
    const allPreviewsImports = previewsAST.find(jscodeshift_1.ImportDeclaration);
    const componentImportDeclaration = jscodeshift_1.importDeclaration([isDefaultExport
            ? jscodeshift_1.importDefaultSpecifier(jscodeshift_1.identifier(componentClassName))
            : jscodeshift_1.importSpecifier(jscodeshift_1.identifier(componentClassName))
    ], jscodeshift_1.stringLiteral(componentPath), "value");
    allPreviewsImports
        .at(0)
        .insertAfter(componentImportDeclaration);
    return allPreviewsImports.toSource();
}
function addComponentToPreview(previewsAST, newComponent) {
    const previews = previewsAST.findJSXElements("Previews");
    const previewsParrentPaths = previews.paths();
    if (previewsParrentPaths.length) {
        const [{ value: { children } }] = previewsParrentPaths;
        children?.push(jscodeshift_1.stringLiteral(newComponent));
        return previews.toSource();
    }
    return previews.toSource();
}
function serializeComponentsProps(componentClassName, componentProps) {
    if (componentClassName !== 'HooksPOCEdit')
        return "";
    return componentProps
        ? Object.entries(componentProps).map(([propName, propValue]) => {
            const serializedPropValue = serializePropValue(propValue);
            return `${propName}={${serializedPropValue}}`;
        }).join(" ")
        : "";
}
function serializePropValue(propValue) {
    switch (typeof propValue) {
        case 'string': return `'${propValue}'`;
        case 'object': return `${JSON.stringify(propValue)}`;
        case 'function': return `${propValue.toString()}`;
        default: return propValue;
    }
}
//# sourceMappingURL=previews-registartion.js.map