"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.deriveFiltersTemplateModel = exports.deriveEntityListTemplateModel = void 0;
const util_1 = require("../../../building-blocks/stages/template-model/pieces/util");
const graphql_1 = require("graphql");
const graphql_tag_1 = __importDefault(require("graphql-tag"));
const BaseTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/BaseTemplateModel");
const ScreenTemplateModel_1 = require("../../../building-blocks/stages/template-model/pieces/amplicode/ScreenTemplateModel");
const getEntityAttributes_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityAttributes");
const getEntityName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getEntityName");
const getAttributeNames_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getAttributeNames");
const getTopFieldName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getTopFieldName");
const getOperationDefinitionName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getOperationDefinitionName");
const getGraphQLTypeByArgumentName_1 = require("../../../building-blocks/stages/template-model/pieces/graphql-utils/getGraphQLTypeByArgumentName");
const utils_1 = require("../../../common/utils");
const deriveEntityListTemplateModel = async (options, answers, schema) => {
    if (schema == null) {
        throw new Error('Schema not found');
    }
    const { componentName, route, query: queryString, mutation: deleteMutationString, type = 'cards', mode = 'edit', idField = 'id', filterByArguments } = answers;
    const queryNode = graphql_tag_1.default(queryString);
    const mutationNode = deleteMutationString != null ? graphql_tag_1.default(deleteMutationString) : undefined;
    const queryName = getTopFieldName_1.getTopFieldName(queryNode);
    const refetchQuery = getOperationDefinitionName_1.getOperationDefinitionName(queryNode);
    const deleteMutationName = mutationNode != null ? getTopFieldName_1.getTopFieldName(mutationNode) : undefined;
    const attributes = getEntityAttributes_1.getEntityAttributes(queryNode, schema, idField);
    const entityName = getEntityName_1.getEntityName(queryName, schema);
    const allAttributes = getAttributeNames_1.getAttributeNames(entityName, schema);
    return {
        ...BaseTemplateModel_1.baseTemplateModel,
        ...util_1.templateUtilities,
        ...ScreenTemplateModel_1.deriveScreenTemplateModel(options, answers, schema),
        ...deriveFiltersTemplateModel(queryName, filterByArguments, schema),
        componentName,
        route,
        queryName,
        queryString,
        deleteMutationName,
        deleteMutationString,
        attributes,
        allAttributes,
        idField,
        type,
        mode,
        refetchQuery,
        entityName
    };
};
exports.deriveEntityListTemplateModel = deriveEntityListTemplateModel;
function deriveFiltersTemplateModel(queryName, filterByArguments, schema) {
    let filters = [];
    if (filterByArguments != null) {
        if (schema == null)
            throw new Error('Schema is required for generating filters');
        const listQueryType = schema.getQueryType()?.getFields()[queryName];
        if (listQueryType == null)
            throw new Error('Can\'t find query name in the schema for generating filters');
        filters = filterByArguments.map(argumentName => ({
            argumentName: argumentName.length === 1 ? argumentName[0] : argumentName,
            caption: getFilterCaption(argumentName),
            type: graphql_1.getNamedType(getGraphQLTypeByArgumentName_1.getGraphQLTypeByArgumentName(schema, listQueryType, argumentName)).toString()
        }));
    }
    const filterImports = getFilterImports(filters);
    const withFilters = filters.length > 0;
    return {
        filters,
        filterImports,
        withFilters,
    };
}
exports.deriveFiltersTemplateModel = deriveFiltersTemplateModel;
function getFilterCaption(argumentName) {
    return removeFirstFilterPathString(argumentName)
        .map(argumentNameElem => utils_1.capitalizeFirst(utils_1.splitByCapitalLetter(argumentNameElem)))
        .join(' ');
}
function removeFirstFilterPathString(argumentName) {
    if (argumentName[0] === 'filter' && argumentName.length > 1) {
        const [, ...tail] = argumentName;
        return tail;
    }
    return argumentName;
}
function getFilterImports(filters) {
    return {
        withFilterCheckbox: filters.find(filter => filter.type === 'Boolean') != null,
        withFilterNumber: filters.find(filter => filter.type === 'Int' || filter.type === 'BigInteger' || filter.type === 'Float' || filter.type === 'BigDecimal') != null,
        withFilterString: filters.find(filter => filter.type === 'String') != null,
        withFilterDate: filters.find(filter => filter.type === 'Date' || filter.type === 'Time' || filter.type === 'DateTime') != null,
    };
}
//# sourceMappingURL=template-model.js.map