"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const js_yaml_1 = __importDefault(require("js-yaml"));
const path_1 = __importDefault(require("path"));
const chai_1 = require("chai");
const assert_1 = __importDefault(require("assert"));
const commons_1 = require("../../commons");
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'app');
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'app');
const answers = {
    appTitle: 'Amplicode Petclinic',
    appShortName: 'ampl-petclinic',
    graphqlUri: '/graphql',
    basePath: 'front',
    menuType: 'vertical'
};
describe('codegen app test', () => {
    it('should generate app (single schema file)', async () => {
        await commons_1.cleanup(DEST_DIR);
        const codegenConfigPath = path_1.default.join(DEST_DIR, 'codegen.yml');
        const devEnvPath = path_1.default.join(DEST_DIR, '.env.development');
        const prodEnvPath = path_1.default.join(DEST_DIR, '.env.production');
        // check that we remove previously generated app
        assert_1.default.ok(!fs_1.default.existsSync(codegenConfigPath));
        assert_1.default.ok(!fs_1.default.existsSync(devEnvPath));
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        assert_1.default.ok(fs_1.default.existsSync(codegenConfigPath));
        assert_1.default.ok(fs_1.default.existsSync(devEnvPath));
        assert_1.default.ok(fs_1.default.existsSync(prodEnvPath));
        const doc = js_yaml_1.default.load(fs_1.default.readFileSync(codegenConfigPath, 'utf-8'));
        chai_1.expect(doc.schema).eq('./src/core/schema/schema.graphql');
        chai_1.expect(fs_1.default.readFileSync(devEnvPath, 'utf-8')).to.contain('VITE_GRAPHQL_URI=/graphql');
        chai_1.expect(fs_1.default.readFileSync(prodEnvPath, 'utf-8')).to.contain('VITE_GRAPHQL_URI=/graphql');
        const appSchemaPath = path_1.default.join(DEST_DIR, 'src', 'core', 'schema', 'schema.graphql');
        chai_1.expect(fs_1.default.readFileSync(appSchemaPath, 'utf-8')).to.contain('type PetDTO {');
        chai_1.expect(fs_1.default.readFileSync(appSchemaPath, 'utf-8')).not.to.contain('type TestEntity {');
    });
    it('should generate app (composite schema)', async () => {
        const schemaPaths = [commons_1.SCHEMA_PATH, commons_1.SCHEMA2_PATH];
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, schemaPaths));
        const appSchemaPath = path_1.default.join(DEST_DIR, 'src', 'core', 'schema', 'schema.graphql');
        chai_1.expect(fs_1.default.readFileSync(appSchemaPath, 'utf-8')).to.contain('type PetDTO {');
        chai_1.expect(fs_1.default.readFileSync(appSchemaPath, 'utf-8')).to.contain('type TestEntity {');
    });
});
//# sourceMappingURL=app.test.js.map