"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const queries_1 = require("../common/queries");
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-details');
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-details');
describe('codegen entity-details test', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate entity details screen - Owner', async () => {
        const detailsAnswers = {
            query: queries_1.getOwnerQuery,
            componentName: 'OwnerDetails',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'OwnerDetails.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, detailsAnswers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function OwnerDetails');
        chai_1.expect(componentFile).to.contain('query Get_Owner($id: BigInteger) {');
    });
    it('should generate entity details screen - ScalarsTestEntity', async () => {
        const detailsAnswers = {
            query: queries_1.scalarsDetailsQuery,
            componentName: 'ScalarsDetails',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ScalarsDetails.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, detailsAnswers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ScalarsDetails');
        chai_1.expect(componentFile).to.contain('query Get_Scalars($id: ID) {');
        chai_1.expect((componentFile.match(/<Descriptions.Item/g) || []).length).to.eq(24);
    });
});
//# sourceMappingURL=entity-details.test.js.map