"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const queries_1 = require("../common/queries");
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-details');
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-details');
describe('codegen entity-editor test', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate entity editor screen - Owner', async () => {
        const editorAnswers = {
            query: queries_1.getOwnerQuery,
            route: 'owner-editor',
            refetchQueryName: 'Get_Owner',
            mutation: queries_1.ownerUpsertMutation,
            componentName: 'OwnerEditor',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'OwnerEditor.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, editorAnswers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function OwnerEditor');
        chai_1.expect(componentFile).to.contain('query Get_Owner($id: BigInteger) {');
        chai_1.expect(componentFile).to.contain('mutation Update_Owner($input: OwnerInputDTO) {');
    });
    it('should generate entity editor screen - ScalarsTestEntity', async () => {
        const editorAnswers = {
            query: queries_1.scalarsDetailsQuery,
            route: 'scalars-editor',
            refetchQueryName: 'Get_Scalars',
            mutation: queries_1.scalarsUpsertMutation,
            componentName: 'ScalarsEditor',
            shouldAddToMenu: false
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ScalarsEditor.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, editorAnswers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ScalarsEditor');
        chai_1.expect(componentFile).to.contain('query Get_Scalars($id: ID) {');
        chai_1.expect(componentFile).to.contain('mutation Update_Scalars($input: ScalarsTestEntityInput) {');
    });
});
//# sourceMappingURL=entity-editor.test.js.map