"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const queries_1 = require("../common/queries");
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-list');
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-list');
describe('codegen filter in standalone cards', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('standalone cards with filter', async () => {
        const answers = {
            componentName: 'CardsWithFilterProperty',
            route: 'cards-with-filter-property',
            shouldAddToMenu: false,
            query: queries_1.ownerListQueryWithFilter,
            mutation: queries_1.ownerDeleteMutation,
            filterByArguments: [['filter', 'firstName'], ['filter', 'lastName']]
        };
        const componentPath = path_1.default.join(DEST_DIR, 'CardsWithFilterProperty.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('<Filters onApplyFilters={setFilterVars} />');
        chai_1.expect(componentFile).to.contain('function Filters({ onApplyFilters }: FiltersProps) {');
        chai_1.expect(componentFile).to.contain('type QueryVariablesType = VariablesOf<typeof OWNER_BY_NAMES_LIST>;');
    });
    it('standalone cards without filter', async () => {
        const answersWithoutFilterProperty = {
            componentName: 'CardsWithoutFilterProperty',
            route: 'cards-without-filter-property',
            shouldAddToMenu: false,
            query: queries_1.ownerListQueryWithFilter,
            mutation: queries_1.ownerDeleteMutation,
        };
        const componentWithoutFilterPath = path_1.default.join(DEST_DIR, 'CardsWithoutFilterProperty.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answersWithoutFilterProperty, [commons_1.SCHEMA_PATH]));
        const componentWithoutFilterFile = fs_1.default.readFileSync(componentWithoutFilterPath, 'utf-8');
        chai_1.expect(componentWithoutFilterFile).to.not.contain('<Filters onApplyFilters={setFilterVars} />');
        chai_1.expect(componentWithoutFilterFile).to.not.contain('function Filters({ onApplyFilters }: FiltersProps) {');
    });
    it('standalone cards with empty filter', async () => {
        const answersWithNullFilterProperty = {
            componentName: 'CardsWithNullFilterProperty',
            route: 'cards-with-null-filter-property',
            shouldAddToMenu: false,
            query: queries_1.ownerListQueryWithFilter,
            mutation: queries_1.ownerDeleteMutation,
            filterByArguments: null
        };
        const componentWithNullFilterPath = path_1.default.join(DEST_DIR, 'CardsWithNullFilterProperty.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answersWithNullFilterProperty, [commons_1.SCHEMA_PATH]));
        const componentWithNullFilterFile = fs_1.default.readFileSync(componentWithNullFilterPath, 'utf-8');
        chai_1.expect(componentWithNullFilterFile).to.not.contain('<Filters onApplyFilters={setFilterVars} />');
        chai_1.expect(componentWithNullFilterFile).to.not.contain('function Filters({ onApplyFilters }: FiltersProps) {');
        const answersWithEmptyArrayFilterProperty = {
            componentName: 'CardsWithEmptyArrayFilterProperty',
            route: 'cards-with-empty-array-filter-property',
            shouldAddToMenu: false,
            query: queries_1.ownerListQueryWithFilter,
            mutation: queries_1.ownerDeleteMutation,
            filterByArguments: []
        };
        const componentWithEmptyArrayFilterPath = path_1.default.join(DEST_DIR, 'CardsWithEmptyArrayFilterProperty.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answersWithEmptyArrayFilterProperty, [commons_1.SCHEMA_PATH]));
        const componentWithEmptyArrayFilterFile = fs_1.default.readFileSync(componentWithEmptyArrayFilterPath, 'utf-8');
        chai_1.expect(componentWithEmptyArrayFilterFile).to.not.contain('<Filters onApplyFilters={setFilterVars} />');
        chai_1.expect(componentWithEmptyArrayFilterFile).to.not.contain('function Filters({ onApplyFilters }: FiltersProps) {');
    });
});
//# sourceMappingURL=filter-in-standalone-cards.test.js.map