"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-list');
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-list');
const displayNameFunctionFile = path_1.default.join(DEST_DIR, 'core', 'display-name', 'getOwnerDTODisplayName.ts');
describe('codegen standalone cards', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate standalone cards screen - Owner', async () => {
        const answers = {
            componentName: 'StandaloneOwnerCards',
            route: 'standalone-owner-cards',
            shouldAddToMenu: false,
            query: queries_1.ownerListQuery,
            mutation: queries_1.ownerDeleteMutation,
            mode: 'edit',
            type: 'cards'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneOwnerCards.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const expectCardsTag = `
        <Space direction="vertical" className="card-space">
          {items.map(item => (
            <ItemCard item={item} key={item?.id} />
          ))}
        </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneOwnerCards() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Owner($id: BigInteger!) {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectCardsTag);
        // check that displayName function is written for 'cards'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.true;
    });
    it('should generate standalone cards screen - Pet', async () => {
        const answers = {
            componentName: 'StandalonePetCards',
            route: 'standalone-pet-cards',
            shouldAddToMenu: false,
            query: queries_1.petListQuery,
            mutation: queries_1.petDeleteMutation,
            mode: 'edit',
            type: 'cards'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandalonePetCards.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const expectCardsTag = `
        <Space direction="vertical" className="card-space">
          {items.map(item => (
            <ItemCard item={item} key={item?.id} />
          ))}
        </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandalonePetCards() ');
        chai_1.expect(componentFile).to.contain('query Get_Pet_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Pet($id: BigInteger!) {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectCardsTag);
        // check that displayName function is written for 'cards'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.true;
    });
    it('should generate standalone cards screen - ScalarsTestEntity', async () => {
        const answers = {
            componentName: 'StandaloneScalarsCards',
            route: 'standalone-scalars-cards',
            shouldAddToMenu: false,
            query: queries_1.scalarsListQuery,
            mutation: queries_1.scalarsDeleteMutation,
            mode: 'edit',
            type: 'cards'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneScalarsCards.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneScalarsCards() ');
        chai_1.expect(componentFile).to.contain('query Get_Scalars_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Scalars($id: ID!) {');
        chai_1.expect((componentFile.match(/<ValueWithLabel/g) || []).length).to.eq(24);
    });
});
//# sourceMappingURL=standalone-cards.test.js.map