"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-list');
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-list');
const displayNameFunctionFile = path_1.default.join(DEST_DIR, 'core', 'display-name', 'getOwnerDTODisplayName.ts');
describe('codegen standalone list', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate standalone list screen - Owner', async () => {
        const standaloneListAnswers = {
            componentName: 'StandaloneOwnerList',
            route: 'standalone-owner-list',
            shouldAddToMenu: false,
            query: queries_1.ownerListQuery,
            mutation: queries_1.ownerDeleteMutation,
            type: 'list',
            mode: 'edit'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneOwnerList.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, standaloneListAnswers, [commons_1.SCHEMA_PATH]));
        const expectListTag = `
        <Space direction="vertical" className="list-space">
          <List
            itemLayout="horizontal"
            bordered
            dataSource={items}
            renderItem={item => <ListItem item={item} key={item?.id} />}
          />
        </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneOwnerList() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Owner($id: BigInteger!) {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectListTag);
        // check that displayName function is NOT written for 'list'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.false;
    });
    it('should generate standalone list screen - Pet', async () => {
        const answers = {
            componentName: 'StandalonePetList',
            route: 'standalone-pet-list',
            shouldAddToMenu: false,
            query: queries_1.petListQuery,
            mutation: queries_1.petDeleteMutation,
            mode: 'edit',
            type: 'list'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandalonePetList.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const expectCardsTag = `
    <Space direction="vertical" className="list-space">
    <List
      itemLayout="horizontal"
      bordered
      dataSource={items}
      renderItem={item => <ListItem item={item} key={item?.id} />}
      />
    </Space>`;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandalonePetList() ');
        chai_1.expect(componentFile).to.contain('query Get_Pet_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Pet($id: BigInteger!) {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectCardsTag);
        // check that displayName function is written for 'list'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.true;
    });
});
//# sourceMappingURL=standalone-list.test.js.map