"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-list');
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-list');
const displayNameFiles = [
    path_1.default.join(DEST_DIR, 'core', 'display-name', 'getOwnerDTODisplayName.ts'),
    path_1.default.join(DEST_DIR, 'core', 'display-name', 'getPetTypeDTODisplayName.ts')
];
const expectTag = `
    <Space direction="vertical" className="table-space entity-table">
      <Table
        dataSource={dataSource as object[]}
        columns={columns}
        rowClassName={record =>
          (record as ItemType)?.id === selectedRowId ? "table-row-selected" : ""
        }
        onRow={data => {
          return {
            onClick: () => {
              const id = (data as ItemType)?.id;
              setSelectedRowId(id === selectedRowId ? null : id);
            }
          };
        }}
        scroll={{ x: true }}
      />
    </Space>`;
describe('codegen standalone table', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate standalone table screen - Owner', async () => {
        const answers = {
            componentName: 'StandaloneOwnerTable',
            route: 'standalone-owner-table',
            shouldAddToMenu: false,
            query: queries_1.ownerListQuery,
            mutation: queries_1.ownerDeleteMutation,
            type: 'table',
            mode: 'edit'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandaloneOwnerTable.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(componentPath)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandaloneOwnerTable() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Owner($id: BigInteger!) {');
        // columns
        chai_1.expect(componentFile).to.contain('title: "Address",');
        chai_1.expect(componentFile).to.contain('title: "City",');
        chai_1.expect(componentFile).to.contain('title: "Email",');
        chai_1.expect(componentFile).to.contain('title: "First Name",');
        chai_1.expect(componentFile).to.contain('title: "Last Name",');
        chai_1.expect(componentFile).to.contain('title: "Telephone",');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        // check that displayName function is NOT written for 'table'
        displayNameFiles.forEach(file => chai_1.expect(fs_1.default.existsSync(file)).to.be.false);
    });
    it('should generate standalone table screen - Pet', async () => {
        const answers = {
            componentName: 'StandalonePetTable',
            route: 'standalone-pet-table',
            shouldAddToMenu: false,
            query: queries_1.petListQuery,
            mutation: queries_1.petDeleteMutation,
            mode: 'edit',
            type: 'table'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'StandalonePetTable.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(componentPath)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const expectDataSource = `
      const dataSource = items
        .filter(item => item != null)
        .map(item => ({
          ...item,
          ...{
            birthDate: item!.birthDate?.format("LL") ?? undefined,
            type: getPetTypeDTODisplayName(item!.type ?? undefined),
            owner: getOwnerDTODisplayName(item!.owner ?? undefined)
          }
        }));    
    `;
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function StandalonePetTable() ');
        chai_1.expect(componentFile).to.contain('query Get_Pet_List {');
        chai_1.expect(componentFile).to.contain('mutation Delete_Pet($id: BigInteger!) {');
        // columns
        chai_1.expect(componentFile).to.contain('title: "Birth Date",');
        chai_1.expect(componentFile).to.contain('title: "Identification Number",');
        chai_1.expect(componentFile).to.contain('title: "Owner",');
        chai_1.expect(componentFile).to.contain('title: "Type",');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectDataSource);
        // check that displayName function is written for 'table'
        displayNameFiles.forEach(file => chai_1.expect(fs_1.default.existsSync(file)).to.be.true);
    });
});
//# sourceMappingURL=standalone-table.test.js.map