"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const queries_1 = require("../common/queries");
const test_commons_1 = require("../../../test-commons");
const utils_1 = require("../../../../common/utils");
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-lookup');
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-lookup');
const displayNameFunctionFile = path_1.default.join(DEST_DIR, 'core', 'display-name', 'getOwnerDTODisplayName.ts');
describe('codegen lookup cards', () => {
    before(async () => { await commons_1.cleanup(DEST_DIR); });
    it('should generate lookup cards screen - Owner', async () => {
        const answers = {
            componentName: 'OwnerLookup',
            route: 'owner-lookup-cards',
            query: queries_1.ownerListQuery
        };
        const componentPath = path_1.default.join(DEST_DIR, 'OwnerLookup.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(componentPath)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function OwnerLookup(props: OwnerLookupProps) {');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        const expectTag = `
      <div className="narrow-layout">
        <Space direction="vertical" className="card-space">
          <Cards
            items={items}
            loading={loading}
            error={error}
            onSelect={item => {
              props.onSelect != null && props.onSelect(item);
            }}
          />
          {/* <Pagination /> - in future */}
        </Space>
      </div>`;
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        ['First Name', 'Last Name', 'City', 'Address', 'Telephone', 'Email'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field} ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
        });
        // check that displayName function is written for 'lookup'
        chai_1.expect(fs_1.default.existsSync(displayNameFunctionFile)).to.be.true;
    });
    it('should generate lookup cards screen - ScalarsTestEntity', async () => {
        const answers = {
            componentName: 'ScalarsLookupCards',
            route: 'scalars-lookup-cards',
            query: queries_1.scalarsListQuery
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ScalarsLookupCards.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(componentPath)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ScalarsLookupCards(props: ScalarsLookupCardsProps) {');
        chai_1.expect(componentFile).to.contain('query Get_Scalars_List {');
        chai_1.expect((componentFile.match(/<ValueWithLabel/g) || []).length).to.eq(24);
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, `<ValueWithLabel key="url" label="Url" value={item.url ?? undefined} />`);
    });
});
//# sourceMappingURL=lookup-cards.test.js.map