"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const utils_1 = require("../../../../common/utils");
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-management');
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-management');
describe('codegen cards management', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate cards management screens - NotNullTestScalarsEntity', async () => {
        const answers = {
            listComponentName: 'TestNotNullScalarsCards',
            itemComponentName: 'TestNotNullScalarsCardsEditor',
            route: 'notnull-scalars-cards',
            shouldAddToMenu: true,
            listQuery: queries_1.notNullScalarsListQuery,
            detailsQuery: queries_1.notNullScalarsDetailsQuery,
            deleteMutation: queries_1.notNullScalarsDeleteMutation,
            upsertMutation: queries_1.notNullScalarsUpsertMutation,
        };
        const componentPath = path_1.default.join(DEST_DIR, 'TestNotNullScalarsCards.tsx');
        const editorComponentPath = path_1.default.join(DEST_DIR, 'TestNotNullScalarsCardsEditor.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const editorComponentFile = fs_1.default.readFileSync(editorComponentPath, 'utf-8');
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        [
            'Big Decimal Not Null',
            'Big Int Not Null',
            'String Not Null',
        ].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field} ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
        });
        const urlValueWithLabel = `
      <ValueWithLabel
        key="urlNotNull"
        label="Url Not Null"
        value={item.urlNotNull ?? undefined}
        isUrl={true}
      />`;
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, urlValueWithLabel);
        const bigDecimalFormItem = `
      <Form.Item name="bigDecimalNotNull" label="Big Decimal Not Null">
        <InputNumber type={"number"} stringMode={true} autoFocus />
      </Form.Item>`;
        test_commons_1.expectFileContainsIgnoreSpace(editorComponentFile, bigDecimalFormItem);
        const bigIntFormItem = `
      <Form.Item name="bigIntNotNull" label="Big Int Not Null">
        <InputNumber type={"number"} precision={0} stringMode={true} />
      </Form.Item>`;
        test_commons_1.expectFileContainsIgnoreSpace(editorComponentFile, bigIntFormItem);
        const urlFormItem = `
      <Form.Item name="urlNotNull" label="Url Not Null">
        <Input type={"url"} />
      </Form.Item>`;
        test_commons_1.expectFileContainsIgnoreSpace(editorComponentFile, urlFormItem);
        ['Local Time Not Null', 'Offset Time Not Null'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field}?.format("LTS") ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const formItem = `
      <Form.Item name="${field}" label="${label}">
        <TimePicker />
      </Form.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(editorComponentFile, formItem);
        });
        ['Local Date Not Null'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field}?.format("LL") ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const formItem = `
      <Form.Item name="${field}" label="${label}">
        <DatePicker />
      </Form.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(editorComponentFile, formItem);
        });
        ['Date Test Not Null', 'Local Date Time Not Null', 'Offset Date Time Not Null'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field}?.format("LLL") ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const formItem = `
      <Form.Item name="${field}" label="${label}">
        <DatePicker showTime={{ format: "HH:mm:ss" }} />
      </Form.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(editorComponentFile, formItem);
        });
    });
});
//# sourceMappingURL=management-cards.test.js.map