"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const utils_1 = require("../../../../common/utils");
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-management');
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-management');
const expectTag = `
      <Space direction="vertical" className="list-space">
        <List
          itemLayout="horizontal"
          bordered
          dataSource={items}
          renderItem={item => <ListItem item={item} key={item?.id} />}
        />
      </Space>`;
describe('codegen readonly list', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate readonly list screen - Owner', async () => {
        const answers = {
            listComponentName: 'ReadOnlyOwnerList',
            itemComponentName: 'ReadOnlyOwnerListDetails',
            route: 'read-only-owner-list',
            shouldAddToMenu: true,
            listQuery: queries_1.ownerListQuery,
            detailsQuery: queries_1.ownerDetailsQuery,
            mode: 'view with details',
            type: 'list'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ReadOnlyOwnerList.tsx');
        const detailsComponentPath = path_1.default.join(DEST_DIR, 'ReadOnlyOwnerListDetails.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ReadOnlyOwnerList() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        const detailsComponentFile = fs_1.default.readFileSync(detailsComponentPath, 'utf-8');
        chai_1.expect(detailsComponentFile).to.contain('query Get_Owner($id: BigInteger) {');
        ['First Name', 'Last Name', 'City', 'Address', 'Telephone', 'Email'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field} ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const descriptions = `
        <Descriptions.Item label={<strong>${label}</strong>}>
          {item.${field} ?? undefined}
        </Descriptions.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(detailsComponentFile, descriptions);
        });
    });
    it('should generate readonly list screen - Pet', async () => {
        const answers = {
            listComponentName: 'ReadOnlyPetList',
            itemComponentName: 'ReadOnlyPetListDetails',
            route: 'read-only-pet-list',
            shouldAddToMenu: true,
            listQuery: queries_1.petListQuery,
            detailsQuery: queries_1.petDetailsQuery,
            mode: 'view with details',
            type: 'list'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ReadOnlyPetList.tsx');
        const detailsComponentPath = path_1.default.join(DEST_DIR, 'ReadOnlyPetListDetails.tsx');
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ReadOnlyPetList() ');
        chai_1.expect(componentFile).to.contain('query Get_Pet_List {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        const detailsComponentFile = fs_1.default.readFileSync(detailsComponentPath, 'utf-8');
        chai_1.expect(detailsComponentFile).to.contain('query Get_Pet($id: BigInteger) {');
        // fields
        ['Identification Number'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field} ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const descriptions = `
        <Descriptions.Item label={<strong>${label}</strong>}>
          {item.${field} ?? undefined}
        </Descriptions.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(detailsComponentFile, descriptions);
        });
        // Date fields
        ['Birth Date'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={item.${field}?.format("LL") ?? undefined}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const descriptions = `
        <Descriptions.Item label={<strong>${label}</strong>}>
          {item.${field}?.format("LL") ?? undefined}
        </Descriptions.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(detailsComponentFile, descriptions);
        });
        // relation fields
        ['Owner'].forEach(label => {
            const field = utils_1.unCapitalizeFirst(label.replace(" ", ""));
            const valueWithLabel = `
      <ValueWithLabel
        key="${field}"
        label="${label}"
        value={get${utils_1.capitalizeFirst(field)}DTODisplayName(item.${field} ?? undefined)}
      />`;
            test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
            const descriptions = `
        <Descriptions.Item label={<strong>${label}</strong>}>
          {get${utils_1.capitalizeFirst(field)}DTODisplayName(item.${field} ?? undefined)}
        </Descriptions.Item>`;
            test_commons_1.expectFileContainsIgnoreSpace(detailsComponentFile, descriptions);
        });
        // enum PetType
        const valueWithLabel = `
      <ValueWithLabel
        key="type"
        label="Type"
        value={getPetTypeDTODisplayName(item.type ?? undefined)}
      />`;
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, valueWithLabel);
        const descriptions = `
        <Descriptions.Item label={<strong>Type</strong>}>
          {getPetTypeDTODisplayName(item.type ?? undefined)}
        </Descriptions.Item>`;
        test_commons_1.expectFileContainsIgnoreSpace(detailsComponentFile, descriptions);
    });
});
//# sourceMappingURL=readonly-list.test.js.map