"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const commons_1 = require("../../commons");
const chai_1 = require("chai");
const test_commons_1 = require("../../../test-commons");
const queries_1 = require("../common/queries");
const GENERATOR_DIR = path_1.default.join(commons_1.GENERATORS_DIR, 'entity-management');
const DEST_DIR = path_1.default.join(commons_1.GENERATORS_DEST_DIR, 'entity-management');
const displayNameFiles = [
    path_1.default.join(DEST_DIR, 'core', 'display-name', 'getOwnerDTODisplayName.ts'),
    path_1.default.join(DEST_DIR, 'core', 'display-name', 'getPetTypeDTODisplayName.ts')
];
const expectTag = `
      <Space direction="vertical" className="table-space">
        <TableSection
          items={items}
          loading={loading}
          error={error}
          selectedRowId={selectedRowId}
          setSelectedRowId={setSelectedRowId}
        />
        {/* <Pagination /> - in future */}
      </Space>`;
describe('codegen readonly table', () => {
    beforeEach(async () => await commons_1.cleanup(DEST_DIR));
    it('should generate readonly table screen - Owner', async () => {
        const answers = {
            listComponentName: 'ReadOnlyOwnerTable',
            itemComponentName: 'ReadOnlyOwnerTableDetails',
            route: 'read-only-owner-table',
            shouldAddToMenu: true,
            listQuery: queries_1.ownerListQuery,
            detailsQuery: queries_1.ownerDetailsQuery,
            mode: 'view with details',
            type: 'table'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ReadOnlyOwnerTable.tsx');
        const detailsComponentPath = path_1.default.join(DEST_DIR, 'ReadOnlyOwnerTableDetails.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(componentPath)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ReadOnlyOwnerTable() ');
        chai_1.expect(componentFile).to.contain('query Get_Owner_List {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        const detailsComponentFile = fs_1.default.readFileSync(detailsComponentPath, 'utf-8');
        chai_1.expect(detailsComponentFile).to.contain('query Get_Owner($id: BigInteger) {');
        // columns
        chai_1.expect(componentFile).to.contain('title: "Address",');
        chai_1.expect(componentFile).to.contain('title: "City",');
        chai_1.expect(componentFile).to.contain('title: "Email",');
        chai_1.expect(componentFile).to.contain('title: "First Name",');
        chai_1.expect(componentFile).to.contain('title: "Last Name",');
        chai_1.expect(componentFile).to.contain('title: "Telephone",');
        // getXXXName files
        displayNameFiles.forEach(file => chai_1.expect(fs_1.default.existsSync(file)).to.be.false);
    });
    it('should generate readonly table screen - Pet', async () => {
        const answers = {
            listComponentName: 'ReadOnlyPetTable',
            itemComponentName: 'ReadOnlyPetTableDetails',
            route: 'read-only-pet-table',
            shouldAddToMenu: true,
            listQuery: queries_1.petListQuery,
            detailsQuery: queries_1.petDetailsQuery,
            mode: 'view with details',
            type: 'table'
        };
        const componentPath = path_1.default.join(DEST_DIR, 'ReadOnlyPetTable.tsx');
        const detailsComponentPath = path_1.default.join(DEST_DIR, 'ReadOnlyPetTableDetails.tsx');
        // check that cleanup is completed, before test start
        chai_1.expect(fs_1.default.existsSync(componentPath)).to.be.false;
        await commons_1.generate(GENERATOR_DIR, commons_1.opts(DEST_DIR, answers, [commons_1.SCHEMA_PATH]));
        const componentFile = fs_1.default.readFileSync(componentPath, 'utf-8');
        chai_1.expect(componentFile).to.contain('export function ReadOnlyPetTable() ');
        chai_1.expect(componentFile).to.contain('query Get_Pet_List {');
        test_commons_1.expectFileContainsIgnoreSpace(componentFile, expectTag);
        const detailsComponentFile = fs_1.default.readFileSync(detailsComponentPath, 'utf-8');
        chai_1.expect(detailsComponentFile).to.contain('query Get_Pet($id: BigInteger) {');
        // columns
        chai_1.expect(componentFile).to.contain('title: "Birth Date",');
        chai_1.expect(componentFile).to.contain('title: "Identification Number",');
        chai_1.expect(componentFile).to.contain('title: "Owner",');
        chai_1.expect(componentFile).to.contain('title: "Type",');
        // getXXXName files
        displayNameFiles.forEach(file => chai_1.expect(fs_1.default.existsSync(file)).to.be.true);
    });
});
//# sourceMappingURL=readonly-table.test.js.map