"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const path_1 = __importDefault(require("path"));
const yeoman_generator_1 = __importDefault(require("yeoman-generator"));
const yeoman_environment_1 = __importDefault(require("yeoman-environment"));
const fs_1 = __importDefault(require("fs"));
const util_1 = require("util");
const test_commons_1 = require("../../test-commons");
const assert_1 = __importDefault(require("assert"));
const rimraf = util_1.promisify(require('rimraf'));
const TPL_FILE_NAME = 'i18nMappings.ts';
const DEST_DIR = path_1.default.join(process.cwd(), `src/test/generated/templates`);
const GENERATED_FILE = path_1.default.join(DEST_DIR, TPL_FILE_NAME);
const FIXTURES_DIR = path_1.default.join(process.cwd(), `src/test/fixtures/templates`);
class CopyTplGenerator extends yeoman_generator_1.default {
    constructor(args, options) {
        super(args, options);
        this.sourceRoot(path_1.default.join(__dirname, '../../fixtures/templates'));
    }
    // noinspection JSUnusedGlobalSymbols
    processTemplate() {
        // noinspection JSUnusedGlobalSymbols
        const model = {
            isLocaleUsed: () => true
        };
        const tplPath = this.templatePath(`${TPL_FILE_NAME}.ejs`);
        console.log('process template tplPath', fs_1.default.realpathSync(tplPath));
        console.log('dest dir', fs_1.default.realpathSync(DEST_DIR));
        this.fs.copyTpl(tplPath, GENERATED_FILE, model);
    }
}
describe('react generator template processing test', () => {
    it('should correct process ejs template', async () => {
        await rimraf(`${DEST_DIR}/*`);
        !fs_1.default.existsSync(DEST_DIR) && fs_1.default.mkdirSync(DEST_DIR, { recursive: true });
        const env = new yeoman_environment_1.default();
        env.registerStub(CopyTplGenerator, 'CopyTplGenerator');
        await env.run('CopyTplGenerator', {});
        test_commons_1.format(GENERATED_FILE);
        assert_1.default.strictEqual(fs_1.default.readFileSync(GENERATED_FILE, 'utf8'), fs_1.default.readFileSync(path_1.default.join(FIXTURES_DIR, TPL_FILE_NAME), 'utf8'));
    });
});
//# sourceMappingURL=react-generator-process-templates.test.js.map