"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.expectFileContainsIgnoreSpace = exports.getMockSchema = exports.stripNewLines = exports.assertFilesPlain = exports.assertFiles = exports.opts = exports.format = exports.assertContent = void 0;
const assert_1 = __importDefault(require("assert"));
const fs_1 = __importDefault(require("fs"));
const prettier = require("prettier");
const path_1 = __importDefault(require("path"));
const assert_2 = require("assert");
const load_1 = require("@graphql-tools/load");
const chai_1 = require("chai");
function assertContent(actual, expect, multiline = true) {
    assert_1.default.strictEqual(drain(actual, multiline), drain(expect, multiline));
}
exports.assertContent = assertContent;
function drain(content, multiline = true) {
    const result = multiline
        ? content
            .replace(/^\s+/gm, '') //spaces at the line start, and empty lines
        : content
            .replace(/\n/g, ' '); //multiline false - join in one line
    return result
        .replace(/\s{2,}/g, ' ') //two or more spaces with one space
        .trim();
}
function format(file) {
    const formatted = prettier.format(fs_1.default.readFileSync(file, 'utf8'), { parser: "typescript" });
    fs_1.default.writeFileSync(file, formatted, 'utf8');
}
exports.format = format;
function opts(dir, answers, modelPath) {
    return {
        model: modelPath,
        dest: dir,
        debug: true,
        answers: Buffer.from(JSON.stringify(answers)).toString('base64')
    };
}
exports.opts = opts;
/**
 * @deprecated use assertFilesPlain, which is not change file content, it is not required since we are using prettier
 */
function assertFiles(filePath, clientDir, fixturesDir) {
    const actual = fs_1.default.readFileSync(path_1.default.join(clientDir, filePath), 'utf8');
    const expect = fs_1.default.readFileSync(path_1.default.join(fixturesDir, filePath), 'utf8');
    assertContent(actual, expect);
}
exports.assertFiles = assertFiles;
function assertFilesPlain(filePath, clientDir, fixturesDir) {
    const actual = fs_1.default.readFileSync(path_1.default.join(clientDir, filePath), 'utf8');
    const expect = fs_1.default.readFileSync(path_1.default.join(fixturesDir, filePath), 'utf8');
    assert_2.strictEqual(actual, expect);
}
exports.assertFilesPlain = assertFilesPlain;
/**
 * Test can fail when result and fixture contain different line separators (e.g. LF vs CRLF)
 *
 * @param str
 */
function stripNewLines(str) {
    return str.replace(/\r\n|\n/g, '');
}
exports.stripNewLines = stripNewLines;
async function getMockSchema() {
    const schemaPath = path_1.default.join(__dirname, '../../../../scripts/schema/schema.graphql');
    const schemaString = fs_1.default.readFileSync(schemaPath, 'utf-8');
    return await load_1.loadSchema(schemaString, { loaders: [] });
}
exports.getMockSchema = getMockSchema;
function expectFileContainsIgnoreSpace(file, fragment) {
    chai_1.expect(file.replace(/\s/g, '')).to.contain(fragment.replace(/\s/g, ''));
}
exports.expectFileContainsIgnoreSpace = expectFileContainsIgnoreSpace;
//# sourceMappingURL=test-commons.js.map